========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - package
      - |version| |downloads| |wheel|

.. |docs| image:: https://readthedocs.org/projects/otx-misp/badge/?style=flat
    :target: https://readthedocs.org/projects/otx-misp
    :alt: Documentation Status

.. |version| image:: https://img.shields.io/pypi/v/otx-misp.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/otx-misp

.. |downloads| image:: https://img.shields.io/pypi/dm/otx-misp.svg?style=flat
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/otx-misp

.. |wheel| image:: https://img.shields.io/pypi/wheel/otx-misp.svg?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/otx-misp

.. end-badges

Imports Alienvault OTX pulses to a MISP instance.

* Free software: Apache 2.0 license

Installation
============

Python 2 support will be dropped soon.

::

    pip install otx-misp

Documentation
=============

https://otx-misp.readthedocs.io/

Alienvault OTX SDK
==================

All files in the `src/otx_misp/otx` directory are Copyright 2015 AlienVault, Inc. and under the Apache 2.0 license.


